@@ -52,6 +52,8 @@ function(boxdata,xformInfo=NA,...)
 	    {
 	      row.names(boxData$fieldData)[coln2] <- derivedFieldName
 	      names(boxData$data)[coln2] <- derivedFieldName
+#new
+              names(boxData$matrixData)[coln2] <- derivedFieldName
             }
          } else
 	 {
@@ -69,10 +71,14 @@ function(boxdata,xformInfo=NA,...)
            {
             row.names(boxData$fieldData)[i] <- derivedFieldName
             names(boxData$data)[i] <- derivedFieldName
+#new
+            names(boxData$matrixData)[i] <- derivedFieldName
 	   } else
 	   {
             row.names(boxData$fieldData)[j] <- derivedFieldName
             names(boxData$data)[j] <- derivedFieldName
+#new
+	    names(boxData$matrixData)[j] <- derivedFieldName
 	   }
 	 }
        }
